Package: aws
Version: 2.5-7
Date: 2026-07-13
Title: Adaptive Weights Smoothing
Authors@R: c(person("Joerg","Polzehl",role=c("aut","cre"),email="joerg.polzehl@wias-berlin.de"),person("Felix","Anker",role=c("ctb")))
Author: Joerg Polzehl [aut, cre],
  Felix Anker [ctb]
Maintainer: Joerg Polzehl <joerg.polzehl@wias-berlin.de>
Depends: R (>= 3.4.0), awsMethods (>= 1.1-1)
Imports: methods, gsl
Description: We provide a collection of R-functions implementing
    adaptive smoothing procedures in 1D, 2D and 3D. This includes the
    Propagation-Separation Approach to adaptive smoothing,
   the Intersecting Confidence Intervals (ICI), variational approaches and a non-local means filter.
   The package is described in detail in Polzehl J, Papafitsoros K, Tabelow K (2020). 
   Patch-Wise Adaptive Weights Smoothing in R. Journal of Statistical Software, 95(6), 1-27. 
   <doi:10.18637/jss.v095.i06>,
    Usage of the package in MR imaging is illustrated in Polzehl and Tabelow (2023),
   Magnetic Resonance Brain Imaging, 2nd Ed. Appendix A, Springer, Use R! Series.
   <doi:10.1007/978-3-031-38949-8>.
License: GPL (>= 2)
Copyright: This package is Copyright (C) 2005-2024 Weierstrass
        Institute for Applied Analysis and Stochastics.
URL: https://www.wias-berlin.de/people/polzehl/
RoxygenNote: 5.0.1
NeedsCompilation: yes
Packaged: 2026-07-13 16:33:41 UTC; polzehl
Repository: CRAN
Date/Publication: 2026-07-13 17:30:02 UTC
Built: R 4.5.2; aarch64-apple-darwin20; 2026-07-13 18:41:21 UTC; unix
Archs: aws.so.dSYM
