
Components in this directory are copied from other sources. They are
distributed with AWS as a convenience but are not part of AWS.

Note that all of them have a license compatible with AWS.

* ZLib C sources is from Jean-loup Gailly and Mark Adler.

   Copyright (C) 1995-2003 Jean-loup Gailly and Mark Adler

   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
   arising from the use of this software.

   Permission is granted to anyone to use this software for any purpose,
   including commercial applications, and to alter it and redistribute it
   freely, subject to the following restrictions:

   1. The origin of this software must not be misrepresented; you must not
      claim that you wrote the original software. If you use this software
      in a product, an acknowledgment in the product documentation would be
      appreciated but is not required.
   2. Altered source versions must be plainly marked as such, and must not be
      misrepresented as being the original software.
   3. This notice may not be removed or altered from any source distribution.

   Jean-loup Gailly jloup@gzip.org
   Mark Adler madler@alumni.caltech.edu
