
This directory contains a set of ready to use Web design templates.

To ease integration we have used the following design:

- Each directory is self contained and the content must be copied into
  the project. Note that the icons and javascripts directories contain also the
  icons and javascripts code used in the web elements. This is needed for the
  web_elements demo.

- Each graphic elements (icons) is referenced into the templates with the
  alias /we_icons/<icon_name>. So users must provide the right alias
  ("/we_icons/") in the  Web server.

- Each javascripts code is referenced into the templates with the
  alias /we_js/<script>. So users must provide the right alias
  ("/we_js/") in the  Web server.
